<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>MX Package Installer</source>
        <translation>MX Instalador de Paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicaciones Populares</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Informacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Gestionar paquetes populares&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>= Installed packages</source>
        <translation>= Paquetes instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Repositorios habilitados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Elimina todos los paquetes marcados como &amp;quot;autoremovible&amp;quot;. Si desea gestionarlos, seleccione Autoremovible en el cuadro de selección desplegable.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Paquetes autoremovibles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1324"/>
        <source>Upgrade All</source>
        <translation>Actualizar Todo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Instalado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Paquetes totales:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Instalar también los paquetes &quot;Recomendados&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Actualizable:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Ocultar paquetes de Bibliotecas y Desarrolladores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <location filename="../mainwindow.ui" line="1524"/>
        <source>Refresh list</source>
        <translation>Actualizar lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar paquetes según su estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="3054"/>
        <source>All packages</source>
        <translation>Todos los paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="3074"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="3075"/>
        <source>Upgradable</source>
        <translation>Actualizable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1516"/>
        <location filename="../mainwindow.cpp" line="3039"/>
        <location filename="../mainwindow.cpp" line="3076"/>
        <location filename="../mainwindow.cpp" line="3178"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>Not installed</source>
        <translation>No instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2574"/>
        <location filename="../mainwindow.cpp" line="3010"/>
        <location filename="../mainwindow.cpp" line="3077"/>
        <location filename="../mainwindow.cpp" line="3163"/>
        <source>Autoremovable</source>
        <translation>Autoremovible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Paquete actualizable. Versión más reciente disponible en el repositorio seleccionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Nombre del Paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX Repo de Prueba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Versión del Repositorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Versión Instalada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Backports de Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <source>For all users</source>
        <translation>Para todos los usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Para el usuario actual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1541"/>
        <source>Remote (repo):</source>
        <translation>Remoto (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <location filename="../mainwindow.ui" line="1486"/>
        <location filename="../mainwindow.cpp" line="3021"/>
        <source>All apps</source>
        <translation>Todas las aplicaciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>All runtimes</source>
        <translation>Todos los binarios de ejecución</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1496"/>
        <location filename="../mainwindow.cpp" line="3033"/>
        <source>All available</source>
        <translation>Todos disponibles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="3018"/>
        <source>Installed apps</source>
        <translation>Aplicaciones instaladas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1506"/>
        <location filename="../mainwindow.cpp" line="3015"/>
        <source>Installed runtimes</source>
        <translation>Binarios de ejecución instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1511"/>
        <location filename="../mainwindow.cpp" line="3037"/>
        <location filename="../mainwindow.cpp" line="3171"/>
        <location filename="../mainwindow.cpp" line="3172"/>
        <source>All installed</source>
        <translation>Todos los instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1303"/>
        <source>Total items </source>
        <translation>Elementos totales </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Installed apps:</source>
        <translation>Aplicaciones instaladas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1369"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1398"/>
        <source>Total installed size:</source>
        <translation>Tamaño total instalado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1412"/>
        <source>Remove unused runtimes</source>
        <translation>Eliminar los tiempos de ejecución no usados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>Short Name</source>
        <translation>Nombre corto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1254"/>
        <source>Full Package Name</source>
        <translation>Nombre completo del Paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1264"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1558"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Console Output</source>
        <translation>Salida de Consola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responda aquí, o simplemente pulse Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3162"/>
        <location filename="../mainwindow.cpp" line="3168"/>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1639"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1667"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1702"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1708"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1746"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1749"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1755"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1771"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1777"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Uninstalling packages...</source>
        <translation>Desinstalando paquetes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Ejecutando las operaciones de predesinstalación...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Running post-uninstall operations...</source>
        <translation>Ejecutando operaciones posteriores a la desinstalación...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Refreshing sources...</source>
        <translation>Actualizando fuentes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <location filename="../mainwindow.cpp" line="1432"/>
        <location filename="../mainwindow.cpp" line="1601"/>
        <location filename="../mainwindow.cpp" line="1666"/>
        <location filename="../mainwindow.cpp" line="1981"/>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2567"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <location filename="../mainwindow.cpp" line="2693"/>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="2805"/>
        <location filename="../mainwindow.cpp" line="2838"/>
        <location filename="../mainwindow.cpp" line="3271"/>
        <location filename="../mainwindow.cpp" line="3347"/>
        <location filename="../mainwindow.cpp" line="3377"/>
        <location filename="../mainwindow.cpp" line="3479"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Hubo un problema al actualizar las fuentes. Es posible que algunas fuentes no hayan proporcionado actualizaciones. Para obtener más información, consulte: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Could not determine Debian version. Please select your version:</source>
        <translation>No se pudo averiguar que versión de Debian utiliza. Seleccione su versión:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Debian Version</source>
        <translation>Versión de Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Please wait...</source>
        <translation>Por favor, espere...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1113"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Está a punto de usar el repositorio MX de Prueba, cuyos paquetes se proporcionan únicamente con fines de prueba. Es posible que puedan dañar su sistema, por lo que se sugiere que haga una copia de seguridad de su sistema e instale o actualice solo un paquete a la vez. Envíe sus comentarios en el foro para que el paquete se pueda evaluar antes de pasar a principal (Main) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1122"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Está a punto de usar Debian Backports, que contiene paquetes tomados de la próxima versión de Debian (llamada &apos;testing&apos;), ajustados y recompilados para su uso en Debian estable. No se pueden probar tan ampliamente como en las versiones estables de Debian y MX Linux, y se proporcionan tal cual, con riesgo de incompatibilidades con otros componentes en Debian estable. ¡Úselo con cuidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux incluye este repositorio de flatpaks solo para conveniencia de los usuarios y no es responsable de la funcionalidad de los flatpaks individuales. Para obtener más información, consulte flatpaks en Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1138"/>
        <location filename="../mainwindow.cpp" line="3507"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1142"/>
        <source>Do not show this message again</source>
        <translation>No mostrar este mensaje de nuevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Se han seleccionado los siguientes paquetes. Haga clic en Mostrar detalles para ver la lista de cambios.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <location filename="../mainwindow.cpp" line="1433"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet no está disponible, no se podrá descargar la lista de paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1301"/>
        <source>Installing packages...</source>
        <translation>Instalando paquetes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Post-processing...</source>
        <translation>Post-procesamiento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <source>Pre-processing for </source>
        <translation>Pre-procesamiento para </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1405"/>
        <source>Installing </source>
        <translation>Instalando </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>Post-processing for </source>
        <translation>Post-procesamiento para </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1602"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation>Hubo un error al escribir el archivo: %1. Por favor, compruebe si tiene suficiente espacio libre en su disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <source>Downloading package info...</source>
        <translation>Descargando información del paquete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1982"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>El comando dpkg-query devolvió un error. Ejecute &apos;dpkg-query -W&apos; en la terminal y verifique el resultado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2122"/>
        <source>dpkg-query command returned an error, please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>El comando dpkg-query devolvió un error. Ejecute &apos;dpkg-query -W&apos; en la terminal y verifique el resultado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <source>Package info</source>
        <translation>Informacion de paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2260"/>
        <location filename="../mainwindow.cpp" line="3411"/>
        <source>More &amp;info...</source>
        <translation>Más &amp;información...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <source>Packages to be installed: </source>
        <translation>Paquetes a instalar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Processing finished successfully.</source>
        <translation>El proceso finalizó correctamente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2568"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="3272"/>
        <location filename="../mainwindow.cpp" line="3348"/>
        <location filename="../mainwindow.cpp" line="3378"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Problema detectado durante la instalación, inspeccione la salida de la consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2597"/>
        <source>About %1</source>
        <translation>Acerca de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2598"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2600"/>
        <source>Package Installer for MX Linux</source>
        <translation>Instalador de Paquetes para MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2602"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2693"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Hubo un problema desinstalando; por favor revise la salida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Success</source>
        <translation>Exito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Se encontro un problema al desinstalar el programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2806"/>
        <location filename="../mainwindow.cpp" line="2839"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>No se ha podido descargar la lista de paquetes. Por favor, compruebe sus fuentes APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2876"/>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak no esta instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2877"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak no está instalado actualmente.
¿OK para continuar e instalarlo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak no fue instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2939"/>
        <source>Needs re-login</source>
        <translation>Necesita volver a iniciar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2940"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Es posible que deba cerrar sesión/iniciar sesión para ver los elementos instalados en el menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <source>Mark keep</source>
        <translation>Marcar para conservar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3162"/>
        <source>Upgrade</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3300"/>
        <source>Quit?</source>
        <translation>¿Salir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3301"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>El proceso aún se está ejecutando, salir puede dejar el sistema en un estado inestable.&lt;p&gt;&lt;b&gt;¿Está seguro de que desea salir del MX Instalador de Paquetes?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3480"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Problema detectado durante la última operación, por favor inspeccione la salida de la consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3508"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Operación potencialmente peligrosa.
Por favor, asegúrese de comprobar cuidadosamente la lista de paquetes que deben ser eliminados.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gestionar controles remotos de Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Para todos los usuarios</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Para el usuario actual</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>ingrese la URL remota de Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>ingrese la ubicación de Flatpakref para instalar la aplicación</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Añada o elimine controles remotos de flatpak (repositorios), o instale aplicaciones usando la URL o ruta de flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Eliminar el remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Añadir el remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Instalar aplicacion</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>No es removible</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub es el control remoto principal de Flatpak y no se eliminará</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Error al añadir control remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>No se pudo añadir el control remoto: el comando devolvió un error. Comprueba la dirección remota e inténtalo de nuevo.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Correcto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Remoto añadido exitosamente</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>La base de datos dpkg/apt está bloqueada por otro programa: %1
Cierre el programa o espere a que termine el proceso e inténtelo de nuevo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Instalador de Paquetes es una herramienta utilizada para la gestión de paquetes en MX Linux
    - instala programas populares de diferentes fuentes
    - instala programas del repositorio MX Test
    - instala programas del repositorio Debian Backports
    - instala flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Omitir la comprobación en línea si informa falsamente de la falta de acceso a Internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="106"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>You must run this program with admin access.</source>
        <translation>Debe ejecutar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>